@@ -8,7 +8,7 @@ from get_username import GetUserName
 
 
 # Определяем параметры командной строки
-host, port, username = get_client_params(sys.argv, 'client')
+host, port, username = get_client_params()
 
 # Стартуем приложение
 app = QApplication(sys.argv)
